#ifndef MAIL_FRONT__CONSTANTS__H__
#define MAIL_FRONT__CONSTANTS__H__

#define AT '@'
#define CR ((char)13)
#define LF ((char)10)
#define SPACE ((char)32)
#define TAB ((char)9)
#define COLON ':'
#define LBRACE '<'
#define RBRACE '>'
#define PERIOD '.'
#define ESCAPE '\\'
#define QUOTE '"'

#endif
